@@ -1,8 +1,9 @@
-# $Id: mvnorm.R 360 2020-06-09 13:12:57Z thothorn $
+# $Id: mvnorm.R 557 2023-04-24 18:16:23Z thothorn $
 
 rmvnorm <- function(n, mean = rep(0, nrow(sigma)), sigma = diag(length(mean)),
-                   method=c("eigen", "svd", "chol"), pre0.9_9994 = FALSE, checkSymmetry = TRUE)
+                    method=c("eigen", "svd", "chol"), pre0.9_9994 = FALSE, checkSymmetry = TRUE)
 {
+
     if (checkSymmetry && !isSymmetric(sigma, tol = sqrt(.Machine$double.eps),
                      check.attributes = FALSE)) {
         stop("sigma must be a symmetric matrix")
@@ -41,24 +42,26 @@ rmvnorm <- function(n, mean = rep(0, nrow(sigma)), sigma = diag(length(mean)),
 
 dmvnorm <- function (x, mean = rep(0, p), sigma = diag(p), log = FALSE, checkSymmetry = TRUE)
 {
+
     if (is.vector(x))
-	x <- matrix(x, ncol = length(x))
+        x <- matrix(x, ncol = length(x))
     p <- ncol(x)
+
     if(!missing(mean)) {
-	if(!is.null(dim(mean))) dim(mean) <- NULL
-	if (length(mean) != p)
-	    stop("x and mean have non-conforming size")
+        if(!is.null(dim(mean))) dim(mean) <- NULL
+        if (length(mean) != p)
+            stop("x and mean have non-conforming size")
     }
     if(!missing(sigma)) {
-	if (p != ncol(sigma))
-	    stop("x and sigma have non-conforming size")
-	if (checkSymmetry && !isSymmetric(sigma, tol = sqrt(.Machine$double.eps),
-			 check.attributes = FALSE))
-	    stop("sigma must be a symmetric matrix")
+        if (p != ncol(sigma))
+            stop("x and sigma have non-conforming size")
+        if (checkSymmetry && !isSymmetric(sigma, tol = sqrt(.Machine$double.eps),
+                         check.attributes = FALSE))
+            stop("sigma must be a symmetric matrix")
     }
 
     ## <faster code contributed by Matteo Fasiolo mf364 at bath.ac.uk
-    dec <- tryCatch(chol(sigma), error=function(e)e)
+    dec <- tryCatch(base::chol(sigma), error=function(e)e)
     if (inherits(dec, "error")) {
         ## warning("cannot compute chol(sigma)"); return(NaN)
         ## behave the same as dnorm(): return Inf or 0
@@ -66,9 +69,9 @@ dmvnorm <- function (x, mean = rep(0, p), sigma = diag(p), log = FALSE, checkSym
         logretval <- rep.int(-Inf, nrow(x))
         logretval[x.is.mu] <- Inf # and all other f(.) == 0
     } else {
-	tmp <- backsolve(dec, t(x) - mean, transpose = TRUE)
-	rss <- colSums(tmp ^ 2)
-	logretval <- - sum(log(diag(dec))) - 0.5 * p * log(2 * pi) - 0.5 * rss
+        tmp <- backsolve(dec, t(x) - mean, transpose = TRUE)
+        rss <- colSums(tmp ^ 2)
+        logretval <- - sum(log(diag(dec))) - 0.5 * p * log(2 * pi) - 0.5 * rss
     }
     names(logretval) <- rownames(x)
     if(log) logretval else exp(logretval)
